@@ -95,18 +95,18 @@ function defineCommonExtensionSymbols(apiPrivate) {
  * @suppressGlobalPropertiesCheck
  */
 function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook, injectedScriptId) {
-  var chrome = window.chrome || {};
-  var devtools_descriptor = Object.getOwnPropertyDescriptor(chrome, 'devtools');
+  const chrome = window.chrome || {};
+  const devtools_descriptor = Object.getOwnPropertyDescriptor(chrome, 'devtools');
   if (devtools_descriptor)
     return;
 
-  var apiPrivate = {};
+  const apiPrivate = {};
 
   defineCommonExtensionSymbols(apiPrivate);
 
-  var commands = apiPrivate.Commands;
-  var events = apiPrivate.Events;
-  var userAction = false;
+  const commands = apiPrivate.Commands;
+  const events = apiPrivate.Events;
+  let userAction = false;
 
   // Here and below, all constructors are private to API implementation.
   // For a public type Foo, if internal fields are present, these are on
@@ -134,9 +134,9 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     },
 
     removeListener: function(callback) {
-      var listeners = this._listeners;
+      const listeners = this._listeners;
 
-      for (var i = 0; i < listeners.length; ++i) {
+      for (let i = 0; i < listeners.length; ++i) {
         if (listeners[i] === callback) {
           listeners.splice(i, 1);
           break;
@@ -150,8 +150,8 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @param {...} vararg
      */
     _fire: function(vararg) {
-      var listeners = this._listeners.slice();
-      for (var i = 0; i < listeners.length; ++i)
+      const listeners = this._listeners.slice();
+      for (let i = 0; i < listeners.length; ++i)
         listeners[i].apply(null, arguments);
     },
 
@@ -182,7 +182,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @this {EventSinkImpl}
      */
     function dispatchRequestEvent(message) {
-      var request = message.arguments[1];
+      const request = message.arguments[1];
       request.__proto__ = new Request(message.arguments[0]);
       this._fire(request);
     }
@@ -194,8 +194,8 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
   Network.prototype = {
     getHAR: function(callback) {
       function callbackWrapper(result) {
-        var entries = (result && result.entries) || [];
-        for (var i = 0; i < entries.length; ++i) {
+        const entries = (result && result.entries) || [];
+        for (let i = 0; i < entries.length; ++i) {
           entries[i].__proto__ = new Request(entries[i]._requestId);
           delete entries[i]._requestId;
         }
@@ -230,7 +230,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
    * @constructor
    */
   function Panels() {
-    var panels = {
+    const panels = {
       elements: new ElementsPanel(),
       sources: new SourcesPanel(),
     };
@@ -238,7 +238,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     function panelGetter(name) {
       return panels[name];
     }
-    for (var panel in panels)
+    for (const panel in panels)
       this.__defineGetter__(panel, panelGetter.bind(null, panel));
     this.applyStyleSheet = function(styleSheet) {
       extensionServer.sendRequest({command: commands.ApplyStyleSheet, styleSheet: styleSheet});
@@ -247,13 +247,13 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
   Panels.prototype = {
     create: function(title, icon, page, callback) {
-      var id = 'extension-panel-' + extensionServer.nextObjectId();
-      var request = {command: commands.CreatePanel, id: id, title: title, icon: icon, page: page};
+      const id = 'extension-panel-' + extensionServer.nextObjectId();
+      const request = {command: commands.CreatePanel, id: id, title: title, icon: icon, page: page};
       extensionServer.sendRequest(request, callback && callback.bind(this, new ExtensionPanel(id)));
     },
 
     setOpenResourceHandler: function(callback) {
-      var hadHandler = extensionServer.hasHandler(events.OpenResource);
+      const hadHandler = extensionServer.hasHandler(events.OpenResource);
 
       function callbackWrapper(message) {
         // Allow the panel to show itself when handling the event.
@@ -294,7 +294,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @this {EventSinkImpl}
      */
     function dispatchShowEvent(message) {
-      var frameIndex = message.arguments[0];
+      const frameIndex = message.arguments[0];
       if (typeof frameIndex === 'number')
         this._fire(window.parent.frames[frameIndex]);
       else
@@ -320,8 +320,8 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
   PanelWithSidebarImpl.prototype = {
     createSidebarPane: function(title, callback) {
-      var id = 'extension-sidebar-' + extensionServer.nextObjectId();
-      var request = {command: commands.CreateSidebarPane, panel: this._hostPanelName, id: id, title: title};
+      const id = 'extension-sidebar-' + extensionServer.nextObjectId();
+      const request = {command: commands.CreateSidebarPane, panel: this._hostPanelName, id: id, title: title};
       function callbackWrapper() {
         callback(new ExtensionSidebarPane(id));
       }
@@ -333,14 +333,14 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
   function declareInterfaceClass(implConstructor) {
     return function() {
-      var impl = {__proto__: implConstructor.prototype};
+      const impl = {__proto__: implConstructor.prototype};
       implConstructor.apply(impl, arguments);
       populateInterfaceClass(this, impl);
     };
   }
 
   function defineDeprecatedProperty(object, className, oldName, newName) {
-    var warningGiven = false;
+    let warningGiven = false;
     function getter() {
       if (!warningGiven) {
         console.warn(className + '.' + oldName + ' is deprecated. Use ' + className + '.' + newName + ' instead');
@@ -352,18 +352,18 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
   }
 
   function extractCallbackArgument(args) {
-    var lastArgument = args[args.length - 1];
+    const lastArgument = args[args.length - 1];
     return typeof lastArgument === 'function' ? lastArgument : undefined;
   }
 
-  var Button = declareInterfaceClass(ButtonImpl);
-  var EventSink = declareInterfaceClass(EventSinkImpl);
-  var ExtensionPanel = declareInterfaceClass(ExtensionPanelImpl);
-  var ExtensionSidebarPane = declareInterfaceClass(ExtensionSidebarPaneImpl);
-  var PanelWithSidebar = declareInterfaceClass(PanelWithSidebarImpl);
-  var Request = declareInterfaceClass(RequestImpl);
-  var Resource = declareInterfaceClass(ResourceImpl);
-  var TraceSession = declareInterfaceClass(TraceSessionImpl);
+  const Button = declareInterfaceClass(ButtonImpl);
+  const EventSink = declareInterfaceClass(EventSinkImpl);
+  const ExtensionPanel = declareInterfaceClass(ExtensionPanelImpl);
+  const ExtensionSidebarPane = declareInterfaceClass(ExtensionSidebarPaneImpl);
+  const PanelWithSidebar = declareInterfaceClass(PanelWithSidebarImpl);
+  const Request = declareInterfaceClass(RequestImpl);
+  const Resource = declareInterfaceClass(ResourceImpl);
+  const TraceSession = declareInterfaceClass(TraceSessionImpl);
 
   /**
    * @constructor
@@ -399,8 +399,8 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @return {!Object}
      */
     createStatusBarButton: function(iconPath, tooltipText, disabled) {
-      var id = 'button-' + extensionServer.nextObjectId();
-      var request = {
+      const id = 'button-' + extensionServer.nextObjectId();
+      const request = {
         command: commands.CreateToolbarButton,
         panel: this._id,
         id: id,
@@ -416,7 +416,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
       if (!userAction)
         return;
 
-      var request = {command: commands.ShowPanel, id: this._id};
+      const request = {command: commands.ShowPanel, id: this._id};
       extensionServer.sendRequest(request);
     },
 
@@ -437,7 +437,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     },
 
     setExpression: function(expression, rootTitle, evaluateOptions) {
-      var request = {
+      const request = {
         command: commands.SetSidebarContent,
         id: this._id,
         expression: expression,
@@ -471,7 +471,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
   ButtonImpl.prototype = {
     update: function(iconPath, tooltipText, disabled) {
-      var request =
+      const request =
           {command: commands.UpdateButton, id: this._id, icon: iconPath, tooltip: tooltipText, disabled: !!disabled};
       extensionServer.sendRequest(request);
     }
@@ -490,7 +490,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @return {!TraceProvider}
      */
     addTraceProvider: function(categoryName, categoryTooltip) {
-      var id = 'extension-trace-provider-' + extensionServer.nextObjectId();
+      const id = 'extension-trace-provider-' + extensionServer.nextObjectId();
       extensionServer.sendRequest(
           {command: commands.AddTraceProvider, id: id, categoryName: categoryName, categoryTooltip: categoryTooltip});
       return new TraceProvider(id);
@@ -505,14 +505,14 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     this._id = id;
   }
 
-  TraceSessionImpl.prototype =
-  {
+  TraceSessionImpl.prototype = {
     /**
      * @param {string=} url
      * @param {number=} timeOffset
      */
     complete: function(url, timeOffset) {
-      var request = {command: commands.CompleteTraceSession, id: this._id, url: url || '', timeOffset: timeOffset || 0};
+      const request =
+          {command: commands.CompleteTraceSession, id: this._id, url: url || '', timeOffset: timeOffset || 0};
       extensionServer.sendRequest(request);
     }
   };
@@ -526,7 +526,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @this {EventSinkImpl}
      */
     function dispatchRecordingStarted(message) {
-      var sessionId = message.arguments[0];
+      const sessionId = message.arguments[0];
       this._fire(new TraceSession(sessionId));
     }
 
@@ -558,7 +558,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
   InspectedWindow.prototype = {
     reload: function(optionsOrUserAgent) {
-      var options = null;
+      let options = null;
       if (typeof optionsOrUserAgent === 'object') {
         options = optionsOrUserAgent;
       } else if (typeof optionsOrUserAgent === 'string') {
@@ -574,14 +574,14 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
      * @return {?Object}
      */
     eval: function(expression, evaluateOptions) {
-      var callback = extractCallbackArgument(arguments);
+      const callback = extractCallbackArgument(arguments);
       function callbackWrapper(result) {
         if (result.isError || result.isException)
           callback(undefined, result);
         else
           callback(result.value);
       }
-      var request = {command: commands.EvaluateOnInspectedPage, expression: expression};
+      const request = {command: commands.EvaluateOnInspectedPage, expression: expression};
       if (typeof evaluateOptions === 'object')
         request.evaluateOptions = evaluateOptions;
       extensionServer.sendRequest(request, callback && callbackWrapper);
@@ -634,14 +634,14 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     return inspectedTabId;
   }
 
-  var keyboardEventRequestQueue = [];
-  var forwardTimer = null;
+  let keyboardEventRequestQueue = [];
+  let forwardTimer = null;
 
   function forwardKeyboardEvent(event) {
     // We only care about global hotkeys, not about random text
     if (!event.ctrlKey && !event.altKey && !event.metaKey && !/^F\d+$/.test(event.key) && event.key !== 'Escape')
       return;
-    var requestPayload = {
+    const requestPayload = {
       eventType: event.type,
       ctrlKey: event.ctrlKey,
       altKey: event.altKey,
@@ -659,7 +659,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
   function forwardEventQueue() {
     forwardTimer = null;
-    var request = {command: commands.ForwardKeyboardEvent, entries: keyboardEventRequestQueue};
+    const request = {command: commands.ForwardKeyboardEvent, entries: keyboardEventRequestQueue};
     extensionServer.sendRequest(request);
     keyboardEventRequestQueue = [];
   }
@@ -678,7 +678,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
 
     this.registerHandler('callback', this._onCallback.bind(this));
 
-    var channel = new MessageChannel();
+    const channel = new MessageChannel();
     this._port = channel.port1;
     this._port.addEventListener('message', this._onMessage.bind(this), false);
     this._port.start();
@@ -720,34 +720,34 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     },
 
     _registerCallback: function(callback) {
-      var id = ++this._lastRequestId;
+      const id = ++this._lastRequestId;
       this._callbacks[id] = callback;
       return id;
     },
 
     _onCallback: function(request) {
       if (request.requestId in this._callbacks) {
-        var callback = this._callbacks[request.requestId];
+        const callback = this._callbacks[request.requestId];
         delete this._callbacks[request.requestId];
         callback(request.result);
       }
     },
 
     _onMessage: function(event) {
-      var request = event.data;
-      var handler = this._handlers[request.command];
+      const request = event.data;
+      const handler = this._handlers[request.command];
       if (handler)
         handler.call(this, request);
     }
   };
 
   function populateInterfaceClass(interfaze, implementation) {
-    for (var member in implementation) {
+    for (const member in implementation) {
       if (member.charAt(0) === '_')
         continue;
-      var descriptor = null;
+      let descriptor = null;
       // Traverse prototype chain until we find the owner.
-      for (var owner = implementation; owner && !descriptor; owner = owner.__proto__)
+      for (let owner = implementation; owner && !descriptor; owner = owner.__proto__)
         descriptor = Object.getOwnPropertyDescriptor(owner, member);
       if (!descriptor)
         continue;
@@ -760,8 +760,8 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     }
   }
 
-  var extensionServer = new ExtensionServerClient();
-  var coreAPI = new InspectorExtensionAPI();
+  const extensionServer = new ExtensionServerClient();
+  const coreAPI = new InspectorExtensionAPI();
 
   Object.defineProperty(chrome, 'devtools', {value: {}, enumerable: true});
 
@@ -778,9 +778,9 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
     chrome.experimental = chrome.experimental || {};
     chrome.experimental.devtools = chrome.experimental.devtools || {};
 
-    var properties = Object.getOwnPropertyNames(coreAPI);
-    for (var i = 0; i < properties.length; ++i) {
-      var descriptor = Object.getOwnPropertyDescriptor(coreAPI, properties[i]);
+    const properties = Object.getOwnPropertyNames(coreAPI);
+    for (let i = 0; i < properties.length; ++i) {
+      const descriptor = Object.getOwnPropertyDescriptor(coreAPI, properties[i]);
       if (descriptor)
         Object.defineProperty(chrome.experimental.devtools, properties[i], descriptor);
     }
@@ -800,7 +800,7 @@ function injectedExtensionAPI(extensionInfo, inspectedTabId, themeName, testHook
  * @return {string}
  */
 function buildExtensionAPIInjectedScript(extensionInfo, inspectedTabId, themeName, testHook) {
-  var argumentsJSON = [extensionInfo, inspectedTabId || null, themeName].map(_ => JSON.stringify(_)).join(',');
+  const argumentsJSON = [extensionInfo, inspectedTabId || null, themeName].map(_ => JSON.stringify(_)).join(',');
   if (!testHook)
     testHook = () => {};
   return '(function(injectedScriptId){ ' + defineCommonExtensionSymbols.toString() + ';' +
